Bio-related Functions
----------------------

Main
^^^^^^^^^^^^^^^^
*bio_process()*
""""""""""""""""
.. autofunction:: neurokit2.bio_process

*bio_analyze()*
""""""""""""""""""""
.. autofunction:: neurokit2.bio_analyze

